#!/bin/bash
# Edit by taich_wei@163.com
# product_Time:20220801-100000
# Last_Renew:  20240218
# Used for init_server


DIR_BACKUP="/opt/backup-sortOut"
TIME=$(date +"%Y%m%d_%H%M%S")
DIR_WORK="/tmp/.ddup"
DIR_LOG="$DIR_WORK/ddup_logs"
LOG="$DIR_LOG/server_init.base.log_$TIME"

MYHOSTNAME=`hostname`
MY_PROFILE="/root/.taichfile"
MYIP=`ip addr|egrep -o "([0-9]{1,3}\.){3}[0-9]{1,3}" |sort |uniq  |egrep -v "^127|.1$|.255$|.0$"`

[ -e "$DIR_LOG" ] || mkdir -pv "$DIR_LOG"
[ -e "$DIR_BACKUP" ] || mkdir -pv "$DIR_BACKUP"


# 001-创建目录、备份etc目录
create_mydir()
{
echo "============================== >>> 01_常用目录创建" |tee -a $LOG
mkdir -pv /root/tools/sbin /root/greattime/{secret,shlib} /tmp/dir-for_deleting
mkdir -pv /opt/softwares /opt/backup-sortOut /opt/work/{item_install,item_data,item_logs}
mkdir -pv /tmp/.ddup/{ddup_backup,ddup_note,files,scripts,ddup_logs,ddup_Tmp}
echo "如下目录已创建：/root/tools/sbin /root/greattime/{secret,shlib} /tmp/dir-for_deleting /opt/softwares /opt/backup-sortOut /opt/work/{item_install,item_data,item_logs} /tmp/.ddup/{ddup_backup,ddup_note,files,scripts,ddup_logs,ddup_Tmp}" |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
cp -r /etc /opt/backup-sortOut/etc_${TIME}bak
}



# 002_配置个性化用户env，加入常用alias；设置server登录提示语
alias_motd()
{
echo "============================== >>> 02_配置个性化用户env，加入常用alias；设置server登录提示语" |tee -a $LOG
cp /root/.bashrc $DIR_BACKUP/root-.bashrc_${TIME}bak && echo ". $MY_PROFILE" >>  /root/.bashrc
cat >$MY_PROFILE << EOF  
alias ne="netstat -tunlp|grep "
alias ll="/bin/ls --color=auto -lhrt"
alias l2="/bin/ls --color=auto -lh"
alias l3="/bin/ls --color=auto -lhrt  --full-time"
alias grep="grep --color=auto"
EOF

cat >/etc/motd << EOF  
==================== $MYHOSTNAME ========================
 

**********************************************************
     welcome to $MYHOSTNAME .built on $TIME
**********************************************************

   ****************************************************
   *****   ii HOME_SCRIPTS        i9 HOME_WORK    *****

   *****   i1 key to get PID                      *****
   *****   i2 du --max-depth=\$n                   *****
   *****   i3 Findxargsgrep                       *****
   *****   i4 Get java                            *****
   *****   i5 Get IP                              *****
   *****   i7 Check the port is used or not       *****
   *****   i8 Cat with ^$ ^#                      *****
   ****************************************************

EOF
echo " " |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
}



# 003_配置自定义工具
config_mytools()
{
echo "============================== >>> 03_自定义工具" |tee -a $LOG
SECURE_COMMAND="
/usr/sbin/iptables
/usr/bin/pstree
/usr/bin/top
/usr/bin/ps
"
for i in $SECURE_COMMAND ;do
NAME_COMMAND=`echo $i|rev|cut -d/ -f1|rev`
cp $i /root/tools/sbin/sec_$NAME_COMMAND
chmod u+x /root/tools/sbin/*
done
echo " " |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
}




# 004-设置自动任务同步服务器时间
set_servertime()
{
echo "============================== >>> 04_服务器时间配置" |tee -a $LOG
mv /etc/localtime /etc/localtime_etc_${TIME}bak && ln -s /usr/share/zoneinfo/Asia/Shanghai /etc/localtime
yum -y install ntp ntpdate
wait
/usr/sbin/ntpdate ntp1.aliyun.com  && /sbin/hwclock -w
echo "* */1 * * * /usr/sbin/ntpdate ntp1.aliyun.com && /sbin/hwclock -w" >> /var/spool/cron/root
echo " " |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
}



# 005-安装基线工具命令、组件、库
install_basesoft()
{
echo "============================== >>> 05_基础命令安装" |tee -a $LOG
OBJECT_LIST="gcc gcc-c++ crontabs dstat dmidecode chkrootkit iptraf glances rdate hdparm lshw lscpu lsscsi ipciutils fping pigz glibc.i686 libgcc.i686 libxml2.i686 compat-libstdc++-33.i686 bind-utils libxml2 flex byacc libpcap ncurses ncurses-devel libpcap-devel curl-devel make nc sysstat tcpdump iotop nload iftop nethogs mlocate dig nslookup ntp ntpdate pstree net-tools vsftpd vim curl wget telnet lsof zip unzip htop lrzsz"


n=`echo $OBJECT_LIST |sed 's/ /\n/g' |wc -l `
m=1
for i in $OBJECT_LIST
do
echo;echo "======================== >>> $m/$n 正在安装 $i" |tee -a $LOG
echo "yum -y install $i" |tee -a $LOG
yum -y install $i
wait;echo;echo;
let m++
done
echo " " |tee -a $LOG
echo " " |tee -a $LOG
}


# 006_JAVA环境配置
configure_java()
{
echo "============================== >>> 06_JAVA环境配置" |tee -a $LOG
[ -e "/usr/java/jdk1.7" ] || mkdir -pv "/usr/java/jdk1.7"
[ -e "/usr/java/jdk1.8" ] || mkdir -pv "/usr/java/jdk1.8"

java_softinstall()
{
if ls -l /usr/java/jdk1.8
then
TDRY=9
else
JAVA_TAR="./init_soft/java-1.8.0-openjdk-1.8.0.322.b06-1.el7_9.x86_64.tar.gz"
tar zxvf $JAVA_TAR
wait
mv java-1.8.0-openjdk-1.8.0.322.b06-1.el7_9.x86_64 /usr/lib/jvm/ && ln -s /usr/lib/jvm/java-1.8.0-openjdk-1.8.0.322.b06-1.el7_9.x86_64 /usr/java/jdk1.8


cat >> /etc/profile  << EOF  



######################### Configure My Env #########################
export HISTTIMEFORMAT=" %F %T `whoami` "

#1、Environment for ddup
export DDUP_SBIN=/root/tools
export PATH=\$PATH:\$DDUP_SBIN
 
#2、 JAVA变量环境
# export JAVA_HOME=/usr/java/jdk1.7
export JAVA_HOME=/usr/java/jdk1.8
# export CLASSPATH=.:\$JAVA_HOME/jre/lib/rt.jar:\$JAVA_HOME/lib/dt.jar:\$JAVA_HOME/lib/tools.jar
# export PATH=\$PATH:\$JAVA_HOME/jre/bin
export PATH=\$PATH:\$JAVA_HOME/bin
EOF
fi
}
echo "请自行将java放到/usr/java/jdk1.8目录，并手动配置JAVA变量环境" |tee -a $LOG
echo """# ========= JAVA变量环境 =========
export JAVA_HOME=/usr/java/jdk1.8
export PATH=\$PATH:\$JAVA_HOME/bin""" |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
echo " " |tee -a $LOG
}





# 程序开始 ================== >>>
# ====================================================== >>
create_mydir     # 001_创建常用目录、备份etc目录
alias_motd       # 002_设定常用alias、登录提示信息
set_servertime   # 004-设置自动任务同步服务器时间
install_basesoft # 005_安装基础-常用工具命令
configure_java   # 006_配置JAVA环境
config_mytools   # 003_配置自定义工具/root/tools/sbin


